@echo off

:: Set the directory where the script was invoked
set "OUTPUT_PATH=%cd%"

:: Set the directory containing the images to process
set "IMG_PATH=%cd%\Exterior Source\"

:: Full path to SNS-HDR executable
set "EXE_PATH=C:\Program Files\SNS-HDR Pro 2\SNS-HDR.exe"

:: Preset name
set "PRESET=Canon Natural"

:: Check if the "Exterior Source" directory exists
if not exist "%IMG_PATH%" (
    echo "Exterior Source" directory does not exist in %cd%.
)

:: Initialize variables
setlocal enabledelayedexpansion
set count=0
set filelist=
set firstfile=

:: Loop through all JPG files in the "Exterior Source" directory
for %%f in ("%IMG_PATH%*.jpg") do (
    set /a count+=1
    if !count! equ 1 set "firstfile=%%~nf"
    set "filelist=!filelist! "%%f""
    
    :: When count reaches 5, process the files
    if !count! equ 5 (
        :: Generate output filename based on the first file in the batch
        set "tiff_output=%OUTPUT_PATH%\!firstfile!_hdr.tiff"
        set "jpg_output=%OUTPUT_PATH%\!firstfile!_hdr.jpg"
        echo Processing files: !filelist!
        echo Output TIFF: !tiff_output!
        echo Output JPG: !jpg_output!
        "%EXE_PATH%" -tiff16 -srgb -da -preset "%PRESET%" !filelist! -o "!tiff_output!"
        
        :: Convert TIFF to JPG with 100% quality using ImageMagick
        magick convert "!tiff_output!" -quality 100 "!jpg_output!"
        
        :: Remove the TIFF file to save space
        del "!tiff_output!"
        
        :: Reset variables for the next batch
        set count=0
        set filelist=
        set firstfile=
    )
)

:: Process any remaining files if the count is less than 5
if !count! gtr 0 (
    set "tiff_output=%OUTPUT_PATH%\!firstfile!_hdr.tiff"
    set "jpg_output=%OUTPUT_PATH%\!firstfile!_hdr.jpg"
    echo Processing files: !filelist!
    echo Output TIFF: !tiff_output!
    echo Output JPG: !jpg_output!
    "%EXE_PATH%" -tiff16 -srgb -da -preset "%PRESET%" !filelist! -o "!tiff_output!"
    
    :: Convert TIFF to JPG with 100% quality using ImageMagick
    magick convert "!tiff_output!" -quality 100 "!jpg_output!"
    
    :: Remove the TIFF file to save space
    del "!tiff_output!"
)

:: Set the directory where the script was invoked
set "OUTPUT_PATH=%cd%"

:: Set the directory containing the images to process
set "IMG_PATH=%cd%\Alignment Exterior\"

:: Check if the "Alignment Exterior" directory exists
if not exist "%IMG_PATH%" (
    echo "Alignment Exterior" directory does not exist in %cd%.
)

:: Initialize variables
setlocal enabledelayedexpansion
set count=0
set filelist=
set firstfile=

:: Loop through all JPG files in the "Alignment Exterior" directory
for %%f in ("%IMG_PATH%*.jpg") do (
    set /a count+=1
    if !count! equ 1 set "firstfile=%%~nf"
    set "filelist=!filelist! "%%f""
    
    :: When count reaches 5, process the files
    if !count! equ 5 (
        :: Generate output filename based on the first file in the batch
        set "tiff_output=%OUTPUT_PATH%\!firstfile!_hdr.tiff"
        set "jpg_output=%OUTPUT_PATH%\!firstfile!_hdr.jpg"
        echo Processing files: !filelist!
        echo Output TIFF: !tiff_output!
        echo Output JPG: !jpg_output!
        "%EXE_PATH%" -tiff16 -srgb -preset "%PRESET%" !filelist! -o "!tiff_output!"
        
        :: Convert TIFF to JPG with 100% quality using ImageMagick
        magick convert "!tiff_output!" -quality 100 "!jpg_output!"
        
        :: Remove the TIFF file to save space
        del "!tiff_output!"
        
        :: Reset variables for the next batch
        set count=0
        set filelist=
        set firstfile=
    )
)

:: Process any remaining files if the count is less than 5
if !count! gtr 0 (
    set "tiff_output=%OUTPUT_PATH%\!firstfile!_hdr.tiff"
    set "jpg_output=%OUTPUT_PATH%\!firstfile!_hdr.jpg"
    echo Processing files: !filelist!
    echo Output TIFF: !tiff_output!
    echo Output JPG: !jpg_output!
    "%EXE_PATH%" -tiff16 -srgb -preset "%PRESET%" !filelist! -o "!tiff_output!"
    
    :: Convert TIFF to JPG with 100% quality using ImageMagick
    magick convert "!tiff_output!" -quality 100 "!jpg_output!"
    
    :: Remove the TIFF file to save space
    del "!tiff_output!"
)

endlocal